﻿/**
* ******************************************************
*                                                       *
*   Copyright (C) Microsoft. All rights reserved.       *
*                                                       *
*******************************************************
*/
/// <reference path="../../typings/node.d.ts" />
/// <reference path="../../typings/nconf.d.ts" />
/// <reference path="../../typings/vcremote-utils.d.ts" />
/// <reference path="../../typings/vcremote-lib.d.ts" />
/// <reference path="../../typings/express.d.ts" />
/// <reference path="../../typings/express-extensions.d.ts" />
/// <reference path="../../typings/tar.d.ts" />
/// <reference path="../../typings/fstream.d.ts" />
"use strict";
var path = require("path");

var HostSpecifics = require("./host-specifics");
var langSpecifics = require("./language-specifics");
var utils = require("vcremote-utils");

var BuildManager;
(function (BuildManager) {
    var baseBuildDir;

    function init(conf) {
        baseBuildDir = path.resolve(process.cwd(), conf.get("serverDir"), "projects");
        utils.UtilHelper.createDirectoryIfNecessary(baseBuildDir);
        langSpecifics.init({
            baseDir: function () {
                return baseBuildDir;
            },
            certs: function () {
                return HostSpecifics.hostSpecifics.getServerCerts(conf);
            },
            serverConf: function () {
                return conf;
            }
        });
    }
    BuildManager.init = init;

    function shutdown() {
        langSpecifics.close();
    }
    BuildManager.shutdown = shutdown;

    function addNewProject(req, res) {
        langSpecifics.getLanguageSpecifics(req).addProject(req, res);
    }
    BuildManager.addNewProject = addNewProject;

    function addProjectConfig(req, res) {
        langSpecifics.getLanguageSpecifics(req).addProjectConfig(req, res);
    }
    BuildManager.addProjectConfig = addProjectConfig;

    function updateProject(req, res) {
        langSpecifics.getLanguageSpecifics(req).updateProject(req, res);
    }
    BuildManager.updateProject = updateProject;

    function buildProject(req, res) {
        langSpecifics.getLanguageSpecifics(req).buildProject(req, res);
    }
    BuildManager.buildProject = buildProject;

    function getProjects(req, res) {
        langSpecifics.getLanguageSpecifics(req).getProjects(req, res);
    }
    BuildManager.getProjects = getProjects;

    function getDevices(req, res) {
        langSpecifics.getLanguageSpecifics(req).getDevices(req, res);
    }
    BuildManager.getDevices = getDevices;

    function getProjectConfig(req, res) {
        langSpecifics.getLanguageSpecifics(req).getProjectConfig(req, res);
    }
    BuildManager.getProjectConfig = getProjectConfig;

    function getProjectConfigs(req, res) {
        langSpecifics.getLanguageSpecifics(req).getProjectConfigs(req, res);
    }
    BuildManager.getProjectConfigs = getProjectConfigs;

    function retrieveBuild(req, res) {
        langSpecifics.getLanguageSpecifics(req).retrieveBuild(req, res);
    }
    BuildManager.retrieveBuild = retrieveBuild;

    function getBuildLog(req, res) {
        langSpecifics.getLanguageSpecifics(req).getBuildLog(req, res);
    }
    BuildManager.getBuildLog = getBuildLog;

    function installBuild(req, res) {
        langSpecifics.getLanguageSpecifics(req).installBuild(req, res);
    }
    BuildManager.installBuild = installBuild;

    function getBuildStatus(req, res) {
        langSpecifics.getLanguageSpecifics(req).getBuildStatus(req, res);
    }
    BuildManager.getBuildStatus = getBuildStatus;

    function execOpen(req, res) {
        langSpecifics.getLanguageSpecifics(req).execOpen(req, res);
    }
    BuildManager.execOpen = execOpen;

    function getFiles(req, res) {
        langSpecifics.getLanguageSpecifics(req).getFiles(req, res);
    }
    BuildManager.getFiles = getFiles;

    function putFiles(req, res) {
        langSpecifics.getLanguageSpecifics(req).putFiles(req, res);
    }
    BuildManager.putFiles = putFiles;

    function deleteFiles(req, res) {
        langSpecifics.getLanguageSpecifics(req).deleteFiles(req, res);
    }
    BuildManager.deleteFiles = deleteFiles;
})(BuildManager || (BuildManager = {}));

module.exports = BuildManager;
