﻿/**
* ******************************************************
*                                                       *
*   Copyright (C) Microsoft. All rights reserved.       *
*                                                       *
*******************************************************
*/
/// <reference path="../../../typings/node.d.ts" />
/// <reference path="../../../typings/Q.d.ts" />
/// <reference path="../../../typings/vcremote-utils.d.ts" />
/// <reference path="../../../typings/express.d.ts" />
"use strict";
var path = require("path");
var Q = require("q");
var utils = require("vcremote-utils");

var resources = utils.ResourcesManager;

var Win32Specifics = (function () {
    function Win32Specifics() {
    }
    Win32Specifics.prototype.defaults = function (base) {
        var windefaults = {
            serverDir: path.join(process.env.APPDATA, require("../../package").name),
            allowsEmulate: false,
            lang: "en",
            suppressVisualStudioMessage: false
        };
        Object.keys(windefaults).forEach(function (key) {
            if (!(key in base)) {
                base[key] = windefaults[key];
            }
        });

        return base;
    };

    Win32Specifics.prototype.initialize = function () {
        return Q({});
    };

    Win32Specifics.prototype.printUsage = function (language) {
        console.info(resources.getStringForLanguage(language, "UsageInformation"));
    };

    Win32Specifics.prototype.resetServerCert = function (conf) {
        return Q({});
    };

    Win32Specifics.prototype.generateClientCert = function (conf) {
        return Q(0);
    };

    Win32Specifics.prototype.initializeServerCerts = function (conf) {
        return Q({
            newCerts: false,
            getKey: function () {
                throw new Error("Not Implemented");
            },
            getCert: function () {
                throw new Error("Not Implemented");
            },
            getCA: function () {
                throw new Error("Not Implemented");
            }
        });
    };

    Win32Specifics.prototype.getServerCerts = function (conf) {
        return {
            newCerts: false,
            getKey: function () {
                throw new Error("Not Implemented");
            },
            getCert: function () {
                throw new Error("Not Implemented");
            },
            getCA: function () {
                throw new Error("Not Implemented");
            }
        };
    };

    Win32Specifics.prototype.removeAllCertsSync = function (conf) {
        return;
    };

    Win32Specifics.prototype.downloadClientCerts = function (req, res) {
        res.send(404, "Not implemented");
    };
    return Win32Specifics;
})();

var win32Specifics = new Win32Specifics();
module.exports = win32Specifics;
